@@ -13,7 +13,7 @@ our @EXPORT_OK = qw(email);
 
 use parent 'Data::Object::Hash';
 
-our $VERSION = '1.22'; # VERSION
+our $VERSION = '1.23'; # VERSION
 
 my %headers = map {
     my $name = lc $_;
@@ -1019,8 +1019,11 @@ sub prepare_package {
 
     # transport email implicitly
     my $driver   = $email->get('driver')->data;
-    my $sendmail = lc($driver) eq lc('sendmail');
-    my $smtpmail = lc($driver) eq lc('smtp');
+    my $sendmail = lc($driver) eq 'sendmail';
+    my $smtpmail = lc($driver) eq 'smtp';
+
+    # default transport to sendmail
+    $sendmail = 1 unless $sendmail or $smtpmail;
 
     if ($sendmail) {
         my $path = $email->get('path')->data;
@@ -1076,7 +1079,7 @@ Emailesque - Lightweight To-The-Point Email
 
 =head1 VERSION
 
-version 1.22
+version 1.23
 
 =head1 SYNOPSIS
 
@@ -1112,6 +1115,7 @@ The following is an example of the object-oriented interface:
     });
 
     my $result = $email->send;
+
     if ($result->isa('Email::Sender::Failure')) {
         die $result->message;
     }
@@ -1153,22 +1157,22 @@ the hashref of arguments to the keyword, constructor and/or the send method:
     # message body
     $email->message('...') # html or text data
 
-    # message body (must set type to multi)
-    $email->message({
-        text => $text_message,
-        html => $html_messase,
-    })
-
     # email message content type (type: text, html, or multi)
     $email->send({ type => 'text' })
 
+    # message multipart content
+    $email->type('multi') # must set type to multi
+    $email->message({ text => $text_message, html => $html_messase })
+
     # carbon-copy other email addresses
     $email->send({ cc => 'user@site.com' })
-    $email->send({ cc => 'user_a@site.com, user_b@site.com, user_c@site.com' })
+    $email->send({ cc => 'usr1@site.com, usr2@site.com, usr3@site.com' })
+    $email->send({ cc => [qw(usr1@site.com usr2@site.com usr3@site.com)] })
 
     # blind carbon-copy other email addresses
     $email->send({ bcc => 'user@site.com' })
-    $email->send({ bcc => 'user_a@site.com, user_b@site.com, user_c@site.com' })
+    $email->send({ bcc => 'usr1@site.com, usr2@site.com, usr3@site.com' })
+    $email->send({ bcc => [qw(usr1@site.com usr2@site.com usr3@site.com)] })
 
     # specify where email responses should be directed
     $email->send({ reply_to => 'other_email@website.com' })
@@ -1182,22 +1186,26 @@ the hashref of arguments to the keyword, constructor and/or the send method:
     $email->send({ attach => [ $file_path => undef ] })
 
     # send additional headers explicitly
-    $email->new({ headers  => { 'X-Mailer' => '...' } })
+    $email->send({ headers  => { 'X-Mailer' => '...' } })
 
     # send additional headers implicitly
-    $email->new({ x_mailer => '...' } # simpler
+    $email->send({ x_mailer => '...' } # simpler
+
+The default email transport is sendmail. This can be changed by specifying a
+different driver parameter, e.g. smtp, as well as any additional arguments
+required by the transport:
 
     # send mail via smtp
-    {
+    $email->send({
         ...,
         driver  => 'smtp',
         host    => 'smtp.googlemail.com',
         user    => 'account@gmail.com',
         pass    => '****'
-    }
+    })
 
     # send mail via smtp via Google (gmail)
-    {
+    $email->send({
         ...,
         ssl     => 1,
         driver  => 'smtp',
@@ -1205,15 +1213,26 @@ the hashref of arguments to the keyword, constructor and/or the send method:
         port    => 465,
         user    => 'account@gmail.com',
         pass    => '****'
-    }
+    })
+
+    # send mail via smtp via Mailchimp (mandrill)
+    $email->send({
+        ...,
+        ssl     => 0,
+        driver  => 'smtp',
+        host    => 'smtp.mandrillapp.com',
+        port    => 587,
+        user    => 'account@domain.com',
+        pass    => '****'
+    })
 
     # send mail via sendmail
     # path is optional if installed in a standard location
-    {
+    $email->send({
         ...,
         driver  => 'sendmail',
         path    => '/usr/bin/sendmail',
-    }
+    })
 
 =head1 METHODS
 
